"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const ava_1 = require("ava");
const assert = require("assert");
const sinon = require("sinon");
const Koa = require('koa');
const KoaSession2 = require('koa-session2');
const { randomBytes } = require('crypto');
const index_1 = require("../src/index");
const KoaCtx = {
    cookies: {
        get: (key) => {
            return '1234';
        }
    }
};
const KoaApp = {
    use: (...args) => { },
    keys: [],
    createContext: (req, res) => {
        return KoaCtx;
    }
};
ava_1.default.beforeEach(t => {
});
ava_1.default('test koa-session2', (t) => __awaiter(this, void 0, void 0, function* () {
    class Store {
        constructor() {
            this.sessions = new Map();
            this.__timer = new Map();
        }
        getID(length) {
            return randomBytes(length).toString('hex');
        }
        get(sid) {
            return __awaiter(this, void 0, void 0, function* () {
                if (!this.sessions.has(sid))
                    return undefined;
                return JSON.parse(this.sessions.get(sid));
            });
        }
        set(session, { sid = this.getID(24), maxAge = 86400000 } = {}) {
            return __awaiter(this, void 0, void 0, function* () {
                if (this.sessions.has(sid) && this.__timer.has(sid)) {
                    const __timeout = this.__timer.get(sid);
                    if (__timeout)
                        clearTimeout(__timeout);
                }
                if (maxAge) {
                    this.__timer.set(sid, setTimeout(() => this.destroy(sid), maxAge));
                }
                try {
                    this.sessions.set(sid, JSON.stringify(session));
                }
                catch (err) {
                    console.log('Set session error:', err);
                }
                return sid;
            });
        }
        destroy(sid) {
            this.sessions.delete(sid);
            this.__timer.delete(sid);
        }
    }
    KoaApp.keys = ['koa2', 'socketio', 'koa-session2'];
    const sessionOpt = {
        store: new Store(),
        key: '4lKSd^Qma*3'
    };
    KoaApp.use(KoaSession2(sessionOpt));
    let spy1 = sinon.spy(KoaCtx.cookies, 'get');
    const ioMiddleware = index_1.HandleKoaSession2(KoaApp, sessionOpt);
    let socket = {
        request: {},
        reponse: {},
        handshake: {
            headers: {
                cookie: 'true=U3m-ZiUIGqU0JcLEAAAF; 4lKSd^Qma*3=twsVN6rKPz5CJhra9pOn8nczyFww_SN5; 4lKSd^Qma*3.sig=Lnv3NfZtqXArCKbqEM0oucyuMe0; koa:sess=0N1Gwg6wHCmm8bjomEm-PQorSGrFaDQN; koa:sess.sig=DyP5wWdGPFKrHeSWzBoo8UcO4n8',
            }
        }
    };
    let md = ioMiddleware(socket, () => { });
    assert(spy1.withArgs('4lKSd^Qma*3').calledOnce);
    assert(spy1.withArgs('4lKSd^Qma*3').returned('1234'));
    spy1.restore();
    t.is(typeof socket.getSession, 'function');
    let spy2 = sinon.spy(sessionOpt.store, 'get');
    let s = yield socket.getSession();
    assert(spy2.withArgs('1234').calledOnce);
    spy2.restore();
    let next = sinon.spy();
    let socket2 = { handshake: {
            headers: {}
        } };
    let md2 = ioMiddleware(socket2, next);
    assert(next.calledOnce);
    t.is('no cookie', next.getCall(0).args[0].message, 'should throw no cookie');
    next.reset();
    t.pass();
}));
ava_1.default('test koa-generic-sessin', (t) => __awaiter(this, void 0, void 0, function* () {
    const Store = require('koa-generic-session/lib/memory_store');
    KoaApp.keys = ['koa2', 'socketio', 'koa-generic-session'];
    const sessionOpt = {
        store: new Store(),
        key: 'hj23.a#ja0'
    };
    KoaApp.use(KoaSession2(sessionOpt));
    let spy1 = sinon.spy(KoaCtx.cookies, 'get');
    const ioMiddleware = index_1.HandleKoaGenericSession(KoaApp, sessionOpt);
    let socket = {
        request: {},
        reponse: {},
        handshake: {
            headers: {
                cookie: 'true=U3m-ZiUIGqU0JcLEAAAF; 4lKSd^Qma*3=twsVN6rKPz5CJhra9pOn8nczyFww_SN5; 4lKSd^Qma*3.sig=Lnv3NfZtqXArCKbqEM0oucyuMe0; koa:sess=0N1Gwg6wHCmm8bjomEm-PQorSGrFaDQN; koa:sess.sig=DyP5wWdGPFKrHeSWzBoo8UcO4n8',
            }
        }
    };
    let md = ioMiddleware(socket, () => { });
    assert(spy1.withArgs('hj23.a#ja0').calledOnce);
    assert(spy1.withArgs('hj23.a#ja0').returned('1234'));
    spy1.restore();
    t.is(typeof socket.getSession, 'function');
    let spy2 = sinon.spy(sessionOpt.store, 'get');
    let s = yield socket.getSession();
    assert(spy2.withArgs('koa:sess:1234').calledOnce);
    spy2.restore();
    let next = sinon.spy();
    let socket2 = { handshake: {
            headers: {}
        } };
    let md2 = ioMiddleware(socket2, next);
    assert(next.calledOnce);
    t.is('no cookie', next.getCall(0).args[0].message, 'should throw no cookie');
    next.reset();
    t.pass();
}));
ava_1.default('test koa-sessin', (t) => __awaiter(this, void 0, void 0, function* () {
    class Store {
        constructor() {
            this.sessions = new Map();
            this.__timer = new Map();
        }
        getID(length) {
            return randomBytes(length).toString('hex');
        }
        get(sid) {
            return __awaiter(this, void 0, void 0, function* () {
                if (!this.sessions.has(sid))
                    return undefined;
                return JSON.parse(this.sessions.get(sid));
            });
        }
        set(sid = this.getID(24), session, maxAge) {
            return __awaiter(this, void 0, void 0, function* () {
                if (this.sessions.has(sid) && this.__timer.has(sid)) {
                    const __timeout = this.__timer.get(sid);
                    if (__timeout)
                        clearTimeout(__timeout);
                }
                if (maxAge) {
                    this.__timer.set(sid, setTimeout(() => this.destroy(sid), maxAge));
                }
                try {
                    this.sessions.set(sid, JSON.stringify(session));
                }
                catch (err) {
                    console.log('Set session error:', err);
                }
                return sid;
            });
        }
        destroy(sid) {
            this.sessions.delete(sid);
            this.__timer.delete(sid);
        }
    }
    KoaApp.keys = ['koa2', 'socketio', 'koa-session'];
    const sessionOpt = {
        store: new Store(),
        key: '9,fn4&m4la'
    };
    KoaApp.use(KoaSession2(sessionOpt));
    let spy1 = sinon.spy(KoaCtx.cookies, 'get');
    const ioMiddleware = index_1.HandleKoaSession(KoaApp, sessionOpt);
    let socket = {
        request: {},
        reponse: {},
        handshake: {
            headers: {
                cookie: 'true=U3m-ZiUIGqU0JcLEAAAF; 4lKSd^Qma*3=twsVN6rKPz5CJhra9pOn8nczyFww_SN5; 4lKSd^Qma*3.sig=Lnv3NfZtqXArCKbqEM0oucyuMe0; koa:sess=0N1Gwg6wHCmm8bjomEm-PQorSGrFaDQN; koa:sess.sig=DyP5wWdGPFKrHeSWzBoo8UcO4n8',
            }
        }
    };
    let md = ioMiddleware(socket, () => { });
    assert(spy1.withArgs('9,fn4&m4la').calledOnce);
    assert(spy1.withArgs('9,fn4&m4la').returned('1234'));
    spy1.restore();
    t.is(typeof socket.getSession, 'function');
    let spy2 = sinon.spy(sessionOpt.store, 'get');
    let s = yield socket.getSession();
    assert(spy2.withArgs('1234').calledOnce);
    spy2.restore();
    let next = sinon.spy();
    let socket2 = { handshake: {
            headers: {}
        } };
    let md2 = ioMiddleware(socket2, next);
    assert(next.calledOnce);
    t.is('no cookie', next.getCall(0).args[0].message, 'should throw no cookie');
    next.reset();
    t.pass();
}));
//# sourceMappingURL=test.js.map